@@ -14,7 +14,7 @@ use Sub::Quote ();
 
 # RECOMMEND PREREQ: Ref::Util::XS
 
-our $VERSION = 'v0.1.3';
+our $VERSION = 'v0.1.4';
 
 # The names of all methods installed by this module.
 my %MINE;
@@ -32,19 +32,29 @@ sub add_columns {
         next if ref $col;
 
         $col =~ s/^\+//;
-
         my $info = $self->column_info($col);
 
         next unless $info->{data_type} eq 'enum';
 
+        next unless exists $info->{extra}{list};
+
         my $handlers = $info->{extra}{handles} //= sub { "is_" . $_[0] };
 
         next unless $handlers;
 
         if ( Ref::Util::is_plain_coderef($handlers) ) {
-            $info->{extra}{handles} =
-              { map { $handlers->( $_, $col, $class ) // 0 => $_ }
-                  @{ $info->{extra}{list} } };
+            $info->{extra}{handles} = {
+                map {
+
+                    if ( my $method = $handlers->( $_, $col, $class ) ) {
+                        ( $method => $_ )
+                    }
+                    else {
+                        ()
+                    }
+
+                } @{ $info->{extra}{list} }
+            };
             $handlers = $info->{extra}{handles};
         }
 
@@ -96,7 +106,7 @@ DBIx::Class::Helper::Row::Enumeration - Add methods for emum values
 
 =head1 VERSION
 
-version v0.1.3
+version v0.1.4
 
 =head1 SYNOPSIS
 
@@ -192,8 +202,31 @@ altogether.
 
 =head2 Autogenerated Classes
 
-You cannot override the configuration with autogenerated classes.
-This issue will be addressed in a later version.
+You can use column modifiers to update autogenerated classes created
+by the likes of L<DBIx::Class::Schema::Loader>.  However, the C<extra>
+attributes are not deep-merged, so you will have to repeat them when
+if you want to specify custom handlers, e.g.
+
+  # Created by DBIx::Class::Schema::Loader etc.
+  # DO NOT MODIFY THIS OR ANYTHING ABOVE! etc.
+
+  __PACKAGE__->load_components(qw/ Helper::Row::Enumeration /);
+
+  __PACKAGE__->add_columns(
+
+    '+foo', # using default handlers
+
+    '+baz' => {
+        extra   => {
+            list    => [qw/ good bad ugly /],
+            handles => { ... },
+        },
+    },
+
+  );
+
+Note that this is by design, since the intention column modifiers is
+to override existing values.
 
 =head1 SEE ALSO
 
